From 42da47c55106e6bf55f46333c7c50daa48b1a67f Mon Sep 17 00:00:00 2001
From: Bob Vergauwen <bob@vergauwen.me>
Date: Mon, 4 Jul 2022 20:46:25 +0200
Subject: [PATCH] lisp/ob-latex.el: Added latex inputs

* lisp/ob-latex.el (org-babel-execute:latex): Added support for
including external latex files. Using the :inputs header, external files
can be specified to be included at the top of the produced tex
file. All relative file paths are resolved before including the files.
(org-babel-header-args:latex): Added the inputs as a possible header argument

TINYCHANGE
---
 lisp/ob-latex.el | 5 +++++
 1 file changed, 5 insertions(+)

diff --git a/lisp/ob-latex.el b/lisp/ob-latex.el
index 54816bdc5..f0b466d6d 100644
--- a/lisp/ob-latex.el
+++ b/lisp/ob-latex.el
@@ -65,6 +65,7 @@
     (pdfwidth     . :any)
     (headers      . :any)
     (packages     . :any)
+    (inputs       . :any)
     (buffer       . ((yes no))))
   "LaTeX-specific header arguments.")
 
@@ -146,6 +147,10 @@ This function is called by `org-babel-execute-src-block'."
 	     (height (and fit (cdr (assq :pdfheight params))))
 	     (width (and fit (cdr (assq :pdfwidth params))))
 	     (headers (cdr (assq :headers params)))
+	     (inputs (mapcar (lambda (file)
+                           (concat "\\input{" (expand-file-name file) "}"))
+                         (cdr (assq :inputs params))))
+             (headers (append headers inputs))
 	     (in-buffer (not (string= "no" (cdr (assq :buffer params)))))
 	     (org-latex-packages-alist
 	      (append (cdr (assq :packages params)) org-latex-packages-alist)))
-- 
2.30.1 (Apple Git-130)

